@@ -14,10 +14,10 @@ _set_mpl_backend()
 # This is the only place the version is specified and 
 # used in both setup.py and docs/conf.py to set the 
 # version of ggplot.
-__version__ = '0.4.3'
+__version__ = '0.4.5'
 
 from .ggplot import *
-from components import aes
+from .components import aes
 from .geoms import *
 from .scales import *
 from .themes import *
