@@ -3,6 +3,8 @@ import math
 
 class facet_wrap(object):
     def __init__(self, x=None, y=None, ncol=None, nrow=None, scales="free"):
+        if x is None and y is None:
+            raise Exception("You need to specify a variable name: facet_wrap('var')")
         self.x = x
         self.y = y
         self.ncol = ncol
@@ -10,13 +12,20 @@ class facet_wrap(object):
         self.scales = scales
 
     def __radd__(self, gg):
-
-        x = gg.data.get(self.x)
-        y = gg.data.get(self.y)
-        if x is not None:
+        # deepcopy must be the first thing to not change the original object
+        gg = deepcopy(gg)
+        
+        x,y = None, None
+        gg.n_dim_x = 1
+        facets = []
+        if self.x:
+            x = gg.data.get(self.x)
             gg.n_dim_x = x.nunique()
-        if y is not None:
+            facets.append(self.x)
+        if self.y:
+            y = gg.data.get(self.y)
             gg.n_dim_x *= y.nunique()
+            facets.append(self.y)
 
         n_wide = self.ncol
         n_high = self.nrow
@@ -33,12 +42,9 @@ class facet_wrap(object):
             n_high = math.ceil(float(gg.n_dim_x) / n_wide)
 
         gg.n_wide, gg.n_high = int(n_wide), int(n_high)
-        facets = []
-        facets.append(self.x)
-        if self.y:
-            facets.append(self.y)
+
         gg.facets = facets
         gg.facet_type = "wrap"
         gg.facet_scales = self.scales
-
-        return deepcopy(gg)
+        
+        return gg
\ No newline at end of file
