@@ -84,6 +84,8 @@ class ggplot(object):
         self.ylimits = None
         self.scale_y_reverse = None
         self.scale_x_reverse = None
+        self.scale_y_log = None
+        self.scale_x_log = None
         # legend is a dictionary of {legend_type: {visual_value: legend_key}},
         # where legend_type is one of "color", "linestyle", "marker", "size";
         # visual_value is color value, line style, marker character, or size
@@ -279,7 +281,7 @@ class ggplot(object):
                     else:
                         data = self.data
                     for layer in self._get_layers(data, _aes):
-                        plt.subplot(1, 1, 1)
+                        ax = plt.subplot(1, 1, 1)
                         callbacks = geom.plot_layer(layer)
                         if callbacks:
                             for callback in callbacks:
@@ -319,6 +321,10 @@ class ggplot(object):
                 plt.gca().invert_yaxis()
             if self.scale_x_reverse:
                 plt.gca().invert_xaxis()
+            if self.scale_y_log:
+                plt.gca().set_yscale('log', basey=self.scale_y_log)
+            if self.scale_x_log:
+                plt.gca().set_xscale('log', basex=self.scale_x_log)
 
             # TODO: Having some issues here with things that shouldn't have a legend
             # or at least shouldn't get shrunk to accomodate one. Need some sort of
